@@ -1,6 +1,6 @@
 //! size limiter middleware
 
-use async_trait::async_trait;
+use salvo_core::async_trait;
 use salvo_core::http::errors::*;
 use salvo_core::http::HttpBody;
 use salvo_core::prelude::*;
